@@ -2,13 +2,8 @@
 # -*- coding: utf-8 -*-
 
 def sort_longest_match_first(links):
-    keys = {x.keys()[0]:x for x in links}
-    xs = sorted(keys.keys(), key=len, reverse=True)
-    b = []
-    append = b.append
-    for y in xs:
-        append(keys[y])
-    return b
+    links.sort(key=lambda c: len(c.keys()[0]), reverse=True)
+    return links
 
 
 def validate_input(args, _isinstance=isinstance):
